"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
// Workaround to avoid naming issues
const WS = WebSocket;
/**
 * @namespace Browser
 * @author Jonathan Casarrubias
 * @description This namespace will provide adapters for
 * the SDK to work in Browser environments.
 */
var Browser;
(function (Browser) {
    /**
     * @class WebSocket
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * Browser Environment.
     */
    class WebSocket {
        connect(url) {
            this.client = new WS(url);
        }
        on(name, callback) {
            switch (name) {
                case 'message':
                    this.client.onmessage = event => {
                        callback(utils_1.Utils.IsJsonString(event.data)
                            ? JSON.parse(event.data)
                            : event.data);
                    };
                    break;
                case 'error':
                    this.client.onerror = callback;
                    break;
                case 'close':
                    this.client.onclose = callback;
                    break;
                default:
                    throw new Error(`ONIX Client: WebSocket event ${name} is not implemented.`);
            }
        }
        send(something) {
            this.client.send(something);
        }
        open(callback) {
            this.client.onopen = callback;
        }
        close() {
            this.client.close();
        }
        removeAllListeners() {
            this.client.removeAllListeners();
        }
    }
    Browser.WebSocket = WebSocket;
    /**
     * @class HTTP
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * Browser Environment.
     */
    class HTTP {
        async get(url) {
            return new Promise((resolve, reject) => {
                const request = new XMLHttpRequest();
                request.onreadystatechange = function () {
                    if (request.readyState === 4) {
                        const response = utils_1.Utils.IsJsonString(request.responseText)
                            ? JSON.parse(request.responseText)
                            : request.responseText;
                        if (request.status === 200) {
                            resolve(response);
                        }
                        else {
                            reject(response);
                        }
                    }
                };
                request.open('GET', url, true);
                request.send(null);
            });
        }
    }
    Browser.HTTP = HTTP;
    /**
     * @class LocalStorage
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * Browser Environment.
     */
    class LocalStorage {
        setItem(key, value) {
            localStorage.setItem(key, value);
        }
        getItem(key) {
            return localStorage.getItem(key);
        }
        removeItem(key) {
            localStorage.removeItem(key);
        }
        clear() {
            localStorage.clear();
        }
    }
    Browser.LocalStorage = LocalStorage;
})(Browser = exports.Browser || (exports.Browser = {}));
//# sourceMappingURL=browser.adapters.js.map