import { IWS, ILocalStorage } from '../interfaces';
import { IHTTP } from '..';
/**
 * @namespace NodeJS
 * @author Jonathan Casarrubias
 * @description This namespace will provide adapters for the
 * SDK to work in a NodeJS Environment,
 */
export declare namespace NodeJS {
    /**
     * @class WebSocket
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * NodeJS Environment.
     */
    class WebSocket implements IWS {
        client: any;
        connect(url: string): void;
        on(name: string, callback: any): void;
        send(something: string): void;
        open(callback: any): void;
        close(): void;
        removeAllListeners(): void;
    }
    /**
     * @class HTTP
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * NodeJS Environment.
     */
    class HTTP implements IHTTP {
        get(url: string): Promise<object>;
        post(config: any, request: any): Promise<object>;
    }
    /**
     * @class LocalStorage
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * NodeJS Environment.
     *
     * npm install node-localstorage
     */
    class LocalStorage implements ILocalStorage {
        localStorage: any;
        setItem(key: string, value: string): void;
        getItem(key: string): string | null;
        removeItem(key: string): void;
        clear(): void;
    }
}
