"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const WS = require("ws");
const http = require("http");
const https = require("https");
const utils_1 = require("../utils");
const node_localstorage_1 = require("node-localstorage");
/**
 * @namespace NodeJS
 * @author Jonathan Casarrubias
 * @description This namespace will provide adapters for the
 * SDK to work in a NodeJS Environment,
 */
var NodeJS;
(function (NodeJS) {
    /**
     * @class WebSocket
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * NodeJS Environment.
     */
    class WebSocket {
        connect(url) {
            this.client = new WS(url);
        }
        on(name, callback) {
            switch (name) {
                case 'close':
                    this.client.onclose = callback;
                    break;
                default:
                    this.client.on(name, callback);
            }
        }
        send(something) {
            this.client.send(something);
        }
        open(callback) {
            this.client.on('open', callback);
        }
        close() {
            this.client.close();
        }
        removeAllListeners() {
            this.client.removeAllListeners();
        }
    }
    NodeJS.WebSocket = WebSocket;
    /**
     * @class HTTP
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * NodeJS Environment.
     */
    class HTTP {
        async get(url) {
            return new Promise((resolve, reject) => {
                const cb = res => {
                    res.setEncoding('utf8');
                    let body = '';
                    // Concatenate Response
                    res.on('data', data => (body += data));
                    // Resolve Call
                    res.on('end', () => resolve(utils_1.Utils.IsJsonString(body) ? JSON.parse(body) : body));
                    // Rehect on error
                };
                if (url.match(/https:\/\//)) {
                    https.get(url, cb).on('error', e => reject(e));
                }
                else {
                    http.get(url, cb).on('error', e => reject(e));
                }
            });
        }
        async post(config, request) {
            return new Promise((resolve, reject) => {
                // Set request options (Can be overrided from caller)
                const options = Object.assign({
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json',
                    },
                }, config);
                // Create request object
                const req = http.request(options, function (res) {
                    res.setEncoding('utf8');
                    let body = '';
                    // Concatenate Response
                    res.on('data', data => (body += data));
                    // Resolve Call
                    res.on('end', () => {
                        resolve(utils_1.Utils.IsJsonString(body) ? JSON.parse(body) : body);
                    });
                    // Rehect on error
                });
                req.on('error', e => reject(e));
                // write data to request body
                req.write(JSON.stringify(request));
                req.end();
            });
        }
    }
    NodeJS.HTTP = HTTP;
    /**
     * @class LocalStorage
     * @author Jonathan Casarrubias
     * @description This class is used when the SDK is running in a
     * NodeJS Environment.
     *
     * npm install node-localstorage
     */
    class LocalStorage {
        constructor() {
            this.localStorage = new node_localstorage_1.LocalStorage('sdk:storage');
        }
        setItem(key, value) {
            this.localStorage.setItem(key, value);
        }
        getItem(key) {
            return this.localStorage.getItem(key);
        }
        removeItem(key) {
            this.localStorage.removeItem(key);
        }
        clear() {
            this.localStorage.clear();
        }
    }
    NodeJS.LocalStorage = LocalStorage;
})(NodeJS = exports.NodeJS || (exports.NodeJS = {}));
//# sourceMappingURL=node.adapters.js.map