"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const appSettings = require('application-settings');
require('nativescript-websockets');
const WS = WebSocket;
const http = require('http');
/**
 * @namespace Nativescript
 * @author Miguel Serrano
 * @description This namespace will provide adapters for the
 * SDK to work in a Nativescript environment,
 */
var Nativescript;
(function (Nativescript) {
    /**
     * @class WebSocket
     * @author Miguel Serrano
     * @description This class is used when the SDK is running in a
     * Nativescript Environment.
     */
    class WebSocket {
        connect(url) {
            this.client = new WS(url, []);
        }
        on(name, callback) {
            switch (name) {
                case 'message':
                    this.client.addEventListener(name, evt => {
                        callback(evt.data);
                    });
                    break;
                default:
                    throw new Error(`ONIX Client: WebSocket event ${name} is not implemented.`);
            }
        }
        send(something) {
            this.client.send(something);
        }
        open(callback) {
            this.client.addEventListener('open', callback);
        }
        close() {
            this.client.close();
        }
        removeAllListeners() {
            this.client.removeAllListeners();
        }
    }
    Nativescript.WebSocket = WebSocket;
    /**
     * @class HTTP
     * @author Miguel Serrano
     * @description This class is used when the SDK is running in a
     * Nativescript Environment.
     */
    class HTTP {
        get(url) {
            return __awaiter(this, void 0, void 0, function* () {
                return new Promise((resolve, reject) => {
                    http.request({ method: 'GET', url }).then(res => {
                        resolve(res.content.toJSON());
                        // Rehect on error
                    }, e => reject(e));
                });
            });
        }
    }
    Nativescript.HTTP = HTTP;
    /**
     * @class LocalStorage
     * @author Miguel Serrano
     * @description This class is used when the SDK is running in a
     * Nativescript Environment.
     */
    class LocalStorage {
        setItem(key, value) {
            appSettings.setString(key, value);
        }
        getItem(key) {
            return appSettings.getString(key);
        }
        removeItem(key) {
            appSettings.remove(key);
        }
        clear() {
            appSettings.clear();
        }
    }
    Nativescript.LocalStorage = LocalStorage;
})(Nativescript = exports.Nativescript || (exports.Nativescript = {}));
//# sourceMappingURL=nativescript.adapters.js.map