import { Listener } from '../interfaces';
/**
 * @class ListenerCollection
 * @author Jonathan Casarrubias
 * @license MIT
 * @description This class is a memory database
 * that will store listeners from across the onixjs
 * platform.
 */
export declare class ListenerCollection {
    /**
     * @prop ns
     * @description This is the current
     * database namespace, should be modified by
     * executing the namespace method before any
     * other procedure.
     */
    private ns;
    /**
     * @prop namespaces
     * @description This is a list of used namespaces
     * will be used mainly when destroying this collection.
     */
    private nss;
    /**
     * @prop listeners
     * @description In memory collection, contains
     * all the listeners registered within this context.
     */
    private listeners;
    /**
     * @method namespace
     * @param ns
     * @description This method will assign a namespace.
     * Should be executed
     */
    namespace(ns: string): this;
    /**
     * @method namespaces
     * @param ns
     * @description This method returns a list of namespaces
     */
    namespaces(): string[];
    /**
     * @method add
     * @param listener
     * @description This method will add a listener into
     * the current namespace database
     */
    add(listener: Listener): number;
    /**
     * @method remove
     * @param index
     * @description This method will remove a listener from the
     * current namespace.
     */
    remove(index: any): void;
    /**
     * @method broadcast
     * @param handler
     * @description will iterate over a collection list of listeners
     * depending on the current namespace and propagate the received data.
     */
    broadcast(data: any): void;
    /**
     * @method forEach
     * @param handler
     * @description will iterate over a collection list of listeners
     * depending on the current namespace and propagate the received data.
     */
    forEach(handler: any): void;
    /**
     * @method removeNameSpaceListeners
     * @description This method will remove any listener from every
     * collection from any namespace.
     */
    removeNameSpaceListeners(namespace: string): void;
    /**
     * @method removeAllListeners
     * @description This method will remove any listener from every
     * collection from any namespace.
     */
    removeAllListeners(): void;
}
