"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
/**
 * @class Unsubscribe
 * @author Jonathan Casarrubias
 * @license MIT
 * @description This class will provide a way
 * to unsubscribe a stream from the server.
 */
class Unsubscribe {
    /**
     * @constructor
     * @param id
     * @param operation
     * @param config
     * @description This constructor will require the id
     * of the listener to be unsubscribed, the original operation
     * sent to the server in order to request the server to unsubscribe
     * and finally the app config so we can use the listeners database
     * and websocket client to finalize these listeners.
     */
    constructor(id, operation, config) {
        this.id = id;
        this.operation = operation;
        this.config = config;
    }
    /**
     * @method unsubscribe
     * @description This async method will resolve once the server
     * successfully unsubscribes the client from the configured
     * stream operation.
     */
    unsubscribe() {
        return __awaiter(this, void 0, void 0, function* () {
            return new Promise((resolve, reject) => {
                // Create unsubscribe app operation
                const operation = {
                    uuid: utils_1.Utils.uuid(),
                    type: 15 /* ONIX_REMOTE_CALL_STREAM_UNSUBSCRIBE */,
                    message: {
                        rpc: 'unsubscribe',
                        request: {
                            metadata: {
                                stream: false,
                                subscription: this.config.registration().uuid,
                            },
                            payload: this.operation,
                        },
                    },
                };
                // Create a listener for this unsubscription, it will be removed
                // once the server finish with the back process.
                const id = this.config.listeners.add((response) => {
                    if (response.uuid === operation.uuid &&
                        response.type ===
                            16 /* ONIX_REMOTE_CALL_STREAM_UNSUBSCRIBE_RESPONSE */) {
                        // Remove unsubscribe listener
                        this.config.listeners.remove(id);
                        // Remove original stream listener
                        this.config.listeners.remove(this.id);
                        // Resolve promise
                        resolve();
                    }
                });
                // Communicate the server that we want to get rid of this stream subscription
                this.config.client.send(JSON.stringify(operation));
            });
        });
    }
}
exports.Unsubscribe = Unsubscribe;
//# sourceMappingURL=unsubscribe.js.map